Package {probaverse}


Title: Install and Load the 'probaverse' Packages
Version: 0.1.1
Description: The 'probaverse' is a suite of packages designed to facilitate creating advanced statistical models through probability distributions. These packages work best when loaded together because they share a common design philosophy and focus on different aspects of developing statistical models. Inspired by the 'tidyverse' package, the 'probaverse' package makes it easy to load the entire suite of 'probaverse' packages together.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: distionary (≥ 0.2.0), distplyr (≥ 0.3.0), famish (≥ 0.2.1)
URL: https://probaverse.probaverse.com/, https://github.com/probaverse/probaverse
Suggests: testthat (≥ 3.0.0)
Config/testthat/edition: 3
BugReports: https://github.com/probaverse/probaverse/issues
NeedsCompilation: no
Packaged: 2026-09-15 13:20:08 UTC; vincenzocoia
Author: Vincenzo Coia ORCID iD [aut, cre, cph]
Maintainer: Vincenzo Coia <vincenzo.coia@gmail.com>
Repository: CRAN
Date/Publication: 2026-09-15 21:30:02 UTC

probaverse: Install and Load the 'probaverse' Packages

Description

logo

The 'probaverse' is a suite of packages designed to facilitate creating advanced statistical models through probability distributions. These packages work best when loaded together because they share a common design philosophy and focus on different aspects of developing statistical models. Inspired by the 'tidyverse' package, the 'probaverse' package makes it easy to load the entire suite of 'probaverse' packages together.

Author(s)

Maintainer: Vincenzo Coia vincenzo.coia@gmail.com (ORCID) [copyright holder]

See Also

Useful links: