VPSPulse Mirrors

High-Performance Open-Source Archive

Help for package probaverse

Package {probaverse}


Title: Install and Load the 'probaverse' Packages
Version: 0.1.0
Description: The 'probaverse' is a suite of packages designed to facilitate creating advanced statistical models through probability distributions. These packages work best when loaded together because they share a common design philosophy and focus on different aspects of developing statistical models. Inspired by the 'tidyverse' package, the 'probaverse' package makes it easy to load the entire suite of 'probaverse' packages together.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: distionary, distplyr, famish
URL: https://probaverse.probaverse.com/, https://github.com/probaverse/probaverse
Suggests: testthat (≥ 3.0.0)
Config/testthat/edition: 3
BugReports: https://github.com/probaverse/probaverse/issues
NeedsCompilation: no
Packaged: 2025-12-08 21:59:16 UTC; vcoia
Author: Vincenzo Coia [aut, cre, cph]
Maintainer: Vincenzo Coia <vincenzo.coia@gmail.com>
Repository: CRAN
Date/Publication: 2025-12-14 17:10:03 UTC

probaverse: Install and Load the 'probaverse' Packages

Description

logo

The 'probaverse' is a suite of packages designed to facilitate creating advanced statistical models through probability distributions. These packages work best when loaded together because they share a common design philosophy and focus on different aspects of developing statistical models. Inspired by the 'tidyverse' package, the 'probaverse' package makes it easy to load the entire suite of 'probaverse' packages together.

Author(s)

Maintainer: Vincenzo Coia vincenzo.coia@gmail.com [copyright holder]

See Also

Useful links:

Need mirroring services?
Contact our team at info@vpspulse.com.

Mirror powered by VPSpulse

Infrastructure sponsored by VPSPulse & Secure Payments by ArionPay.