Package 'probaverse'

Title: Install and Load the 'probaverse' Packages
Description: The 'probaverse' is a suite of packages designed to facilitate creating advanced statistical models through probability distributions. These packages work best when loaded together because they share a common design philosophy and focus on different aspects of developing statistical models. Inspired by the 'tidyverse' package, the 'probaverse' package makes it easy to load the entire suite of 'probaverse' packages together.
Authors: Vincenzo Coia [aut, cre, cph]
Maintainer: Vincenzo Coia <[email protected]>
License: MIT + file LICENSE
Version: 0.1.0
Built: 2026-06-05 11:32:44 UTC
Source: https://github.com/probaverse/probaverse

Help Index